"""Connect to the hub from LaminDB.

Import the package::

   import lndb_hub

This is the complete API reference:

.. autosummary::
   :toctree: .

"""

__version__ = "0.6.0"  # denote a pre-release for 0.1.0 with 0.1a1

from ._entities import Entities  # noqa
